@@ -135,10 +135,13 @@ linearRelation <- function(mydata,
 
     adj <- 1 ## factors for ratios (oxidant is a percentage)
 
+     ## reset strip color on exit
+    current.strip <- trellis.par.get("strip.background")
+    on.exit(trellis.par.set("strip.background", current.strip))
+
     #greyscale handling
     if (length(cols) == 1 && cols == "greyscale") {
-        #strip
-        current.strip <- trellis.par.get("strip.background")
+
         trellis.par.set(list(strip.background = list(col = "white")))
         #other local colours
         data.col <- "darkgrey"
@@ -385,10 +388,6 @@ linearRelation <- function(mydata,
     output <- list(plot = plt, data = newdata, call = match.call())
     class(output) <- "openair"
 
-    #reset if greyscale
-    if (length(cols) == 1 && cols == "greyscale")
-        trellis.par.set("strip.background", current.strip)
-
     invisible(output)
 
 }
