@@ -219,11 +219,14 @@ polarAnnulus <- function(mydata,
 
     ## greyscale handling
     if (length(cols) == 1 && cols == "greyscale") {
-        ## strip only
-        current.strip <- trellis.par.get("strip.background")
+
         trellis.par.set(list(strip.background = list(col = "white")))
     }
 
+    ## reset strip color on exit
+    current.strip <- trellis.par.get("strip.background")
+    on.exit(trellis.par.set("strip.background", current.strip))
+
     ##extra.args setup
     extra.args <- list(...)
 
@@ -630,10 +633,6 @@ polarAnnulus <- function(mydata,
     output <- list(plot = plt, data = newdata, call = match.call())
     class(output) <- "openair"
 
-                                        #reset if greyscale
-    if (length(cols) == 1 && cols == "greyscale")
-        trellis.par.set("strip.background", current.strip)
-
     invisible(output)
 
 }
